darkhistory.history.tla
=======================

.. automodule:: darkhistory.history.tla

   
   
   .. rubric:: Functions

   .. autosummary::
      :toctree: tla
   
      compton_cooling_rate
      get_history
   
   

   
   
   

   
   
   